from django.conf import settings
from django.contrib.auth import load_backend
from django.contrib.auth.models import AnonymousUser
from django.core import signing
from django.utils.functional import SimpleLazyObject


def get_user(token, user):
    if token:
        try:
            user_id, backend_path = signing.loads(token, salt='nap_token.auth', max_age=settings.SESSION_COOKIE_AGE)
        except signing.SignatureExpired:
            # Quietly show they're logged out
            pass
        except signing.BadSignature:
            # Noisily show they're dodgy
            pass
        else:
            if backend_path in settings.AUTHENTICATION_BACKENDS:
                backend = load_backend(backend_path)
                user = backend.get_user(user_id)
    return user or AnonymousUser()


class NapTokenMiddleware(object):

    def process_request(self, request):
        token = request.META.get('HTTP_AUTHORIZE', '')
        if not token.startswith('Bearer '):
            return
        token = token.split(' ', 1)[1].strip()
        original_user = getattr(request, 'user')
        request.user = SimpleLazyObject(lambda: get_user(token, original_user))



from setuptools import setup, find_packages

with open('README.rst') as fin:
    readme = fin.read()

setup(
    name='nap-token-auth',
    version='0.1.0',
    description='A Minimal Token-Based Auth for Django',
    long_description=readme,
    author='Curtis Maloney',
    author_email='curtis@tinbrain.net',
    url='http://github.com/funkybob/nap-token-auth/',
    keywords=['django', 'token', 'auth', 'api'],
    packages = find_packages(exclude=('tests*',)),
    zip_safe=False,
    classifiers = [
        'Environment :: Web Environment',
        'Framework :: Django',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        # 'Programming Language :: Python :: Implementation :: PyPy',
    ],
    requires = [
        'Django (>=1.8)',
    ],
    install_requires = [
        'Django>=1.8',
    ],
)
